@@ -30,7 +30,7 @@ from datetime     import datetime
 from importlib    import import_module
 # from IPython	import embed
 
-__version__    = '0.1.2'
+__version__    = '0.1.3'
 
 cc = jt.cc()
 
@@ -239,7 +239,7 @@ def load_routine(name, cfg=None, show_trace=False):
 	if nlevels == 1:
 		if type(__builtins__).__name__ == 'dict': routine = __builtins__[levels[0]]
 		else:							routine = getattr(__builtins__, levels[0])
-		if show_trace: print(routine, type(routine).__name__)
+		if show_trace: print(cc.key + 'loading', routine, type(routine).__name__, cc.reset)
 		return routine, None
 
 	if levels[0] not in sys.modules:
@@ -252,26 +252,26 @@ def load_routine(name, cfg=None, show_trace=False):
 	global class_object, class_name
 	if "-object" in cfg:
 		if cfg["-object"] in class_obj:
-			if show_trace: print('loading the requested object', cfg["-object"])
+			if show_trace: print('loading the requested object', cc.key, cfg["-object"], cc.reset)
 			object = class_obj[cfg["-object"]]
 			routine = getattr(object, levels[-1])
 			return routine, module
 	else:
 		if class_name_ in class_obj:
-			if show_trace: print('loading the existing object', class_name_)
+			if show_trace: print('loading the existing object', cc.key, class_name_, cc.reset)
 			object = class_obj[class_name_]
 			routine = getattr(object, levels[-1])
 			return routine, module
 
 	routine = module
-	if show_trace: print(routine, type(routine).__name__)
+	if show_trace: print(cc.key + 'loading', routine, type(routine).__name__, cc.reset)
 	for idx, each in enumerate(levels[1:]):
 		try:
 			routine = getattr(routine, each)
 		except AttributeError:
 			routine = import_module(each, routine)
 
-		if show_trace: print(idx, routine, type(routine).__name__)
+		if show_trace: print(cc.key + 'loading', idx, routine, type(routine).__name__, cc.reset)
 
 		if idx == nlevels - 3:  # -3 indicates the next to the last name
 
